boofun.core.adapters
====================

.. automodule:: boofun.core.adapters


   .. rubric:: Functions

   .. autosummary::

      adapt_callable
      adapt_legacy_function
      adapt_numpy_function
      adapt_sympy_expr
      create_adapter

   .. rubric:: Classes

   .. autosummary::

      BooleanFunctionAdapter
      CallableAdapter
      ExternalLibraryFunction
      LegacyAdapter
      LegacyBooleanFunction
      NumPyAdapter
      SymPyAdapter
